@@ -5,15 +5,14 @@
 Callable modules!  Indexable modules!?
 
 Ever wanted to call a module directly, or index it?  Or just sick of seeing
-``from foo import foo`` in your examples?
+`from foo import foo` in your examples?
 
 Give your module the awesome power of an object, or maybe just save a
-little typing, with ``xmod``.
+little typing, with `xmod`.
 
-``xmod`` is a tiny library that extends a module to do things that normally
+`xmod` is a tiny library that extends a module to do things that normally
 only a class could do - handy for modules that "just do one thing".
 
-
 EXAMPLE: Make a module callable as a function
 
 .. code-block:: python
@@ -53,7 +52,7 @@ __all__ = ('xmod',)
 import functools
 import sys
 
-__version__ = '1.1.3'
+__version__ = '1.2.1'
 
 OMIT = {
     '__class__',
@@ -73,14 +72,14 @@ def xmod(
     extension=None, name=None, full=None, props=None, omit=None, mutable=False
 ):
     """
-    Extend the system module at ``name`` with any Python object.
+    Extend the system module at `name` with any Python object.
 
-    The original module is replaced in ``sys.modules`` by a proxy class
+    The original module is replaced in `sys.modules` by a proxy class
     which delegates attributes to the original module, and then adds
     attributes from the extension.
 
     In the most common use case, the extension is a callable and only the
-    ``__call__`` method is delegated, so ``xmod`` can also be used as a
+    `__call__` method is delegated, so `xmod` can also be used as a
     decorator, both with and without parameters.
 
     ARGUMENTS
@@ -89,32 +88,32 @@ def xmod(
         This includes magic methods like __call__ and __getitem__.
 
       name
-        The name of this symbol in ``sys.modules``.  If this is ``None``
-        then ``xmod`` will use ``extension.__module__``.
+        The name of this symbol in `sys.modules`.  If this is `None`
+        then `xmod` will use `extension.__module__`.
 
-        This only needs to be be set if ``extension`` is _not_ a function or
+        This only needs to be be set if `extension` is _not_ a function or
         class defined in the module that's being extended.
 
-        If the ``name`` argument is given, it should almost certainly be
-        ``__name__``.
+        If the `name` argument is given, it should almost certainly be
+        `__name__`.
 
       full
-        If False, just add extension as a callable.
+        If `False`, just add extension as a callable.
 
-        If True, extend the module with all members of ``extension``.
+        If `True`, extend the module with all members of `extension`.
 
-        If None, the default, add the extension if it's a callable, otherwise
-        extend the module with all members of ``extension``.
+        If `None`, the default, add the extension if it's a callable, otherwise
+        extend the module with all members of `extension`.
 
       mutable:
-        If True, the attributes on the proxy are mutable and write through to
-        the underlying module.  If False, the default, attributes on the proxy
-        cannot be changed.
+        If `True`, the attributes on the proxy are mutable and write through to
+        the underlying module.  If `False`, the default, attributes on the
+        proxy cannot be changed.
 
       omit
         A list of methods _not_ to delegate from the proxy to the extension.
 
-        If ``omit`` is None, it defaults to ``xmod.OMIT``, which seems to
+        If `omit` is None, it defaults to `xmod.OMIT`, which seems to
         work well.
     """
     if extension is None:
@@ -123,10 +122,6 @@ def xmod(
             xmod, name=name, full=full, props=props, omit=omit, mutable=mutable
         )
 
-    name = extension.__module__ if name is None else name
-    module = sys.modules[name]
-    members = {EXTENSION_ATTRIBUTE: extension, WRAPPED_ATTRIBUTE: module}
-
     def method(f):
         @functools.wraps(f)
         def wrapped(self, *args, **kwargs):
@@ -140,13 +135,6 @@ def xmod(
 
         return method(f) if mutable else fail
 
-    if callable(extension):
-        members['__call__'] = method(extension)
-    elif full is False:
-        raise ValueError('extension must be callable if full is False')
-    else:
-        full = True
-
     def prop(k):
         return property(
             method(lambda: getattr(extension, k)),
@@ -154,6 +142,27 @@ def xmod(
             mutator(lambda: delattr(extension, k)),
         )
 
+    name = extension.__module__ if name is None else name
+    module = sys.modules[name]
+    members = {
+        WRAPPED_ATTRIBUTE: module,
+        '__getattr__': method(module.__getattribute__),
+        '__setattr__': mutator(module.__setattr__),
+        '__delattr__': mutator(module.__delattr__),
+        '__doc__': getattr(module, '__doc__'),
+    }
+
+    if callable(extension):
+        members['__call__'] = method(extension)
+        members[EXTENSION_ATTRIBUTE] = staticmethod(extension)
+
+    elif full is False:
+        raise ValueError('extension must be callable if full is False')
+
+    else:
+        members[EXTENSION_ATTRIBUTE] = extension
+        full = True
+
     omit = OMIT if omit is None else set(omit)
     for a in dir(extension) if full else ():
         if a not in omit:
@@ -161,13 +170,10 @@ def xmod(
             is_magic = a.startswith('__') and callable(value)
             members[a] = method(value) if is_magic else prop(a)
 
-    members['__getattr__'] = method(module.__getattribute__)
-    members['__setattr__'] = mutator(module.__setattr__)
-    members['__delattr__'] = mutator(module.__delattr__)
+    def directory(self):
+        return sorted(set(members).union(dir(module)))
 
-    keys = set(members)
-    members['__dir__'] = lambda self: sorted(keys.union(dir(module)))
-    members['__doc__'] = getattr(module, '__doc__')
+    members['__dir__'] = directory
 
     proxy_class = type(name, (object,), members)
     sys.modules[name] = proxy_class()
